# ConfigSpace

A simple python module to manage configuration spaces for algorithm configuration
and hyperparameter optimization tasks. Includes various scripts to translate 
between different text formats for configuration space description. 
Distributed under BSD 3-clause, see LICENSE except all files in the directory
ConfigSpace.nx, which are copied from the networkx package and licensed
under a BSD license.

[![Build Status](https://travis-ci.org/automl/ConfigSpace.svg?branch=master)](https://travis-ci.org/automl/ConfigSpace)

Examples usage can be found in the [SMAC documentation](https://automl.github.io/SMAC3/stable/quickstart.html#using-smac-in-python-svm).
